@@ -4,13 +4,14 @@ from typing import Callable
 
 Id = int
 
+
 @dataclass
 class Zone:
     """ Dataclass to store the zones of the alarm
     """
 
     number: Id
-    name: str = ""
+    name: str = ''
     triggered = False
 
 
@@ -20,7 +21,7 @@ class Output:
     """
 
     number: Id
-    name: str = ""
+    name: str = ''
     on = False
 
 
@@ -39,10 +40,10 @@ class Area:
     """
 
     number: Id
-    name: str = ""
+    name: str = ''
     mode: ArmingMode = ArmingMode.DISARMED
 
 
 ZoneListener = Callable[[Zone], bool]
 AreaListener = Callable[[Area], bool]
-SirenListener = Callable[[bool], bool]
\ No newline at end of file
+SirenListener = Callable[[bool], bool]
