@@ -11,13 +11,13 @@ def to_hex(_bytes: Union[bytes, int]) -> str:
         str: String representation of the byte(s) in hexadecimal format
     """
 
-    _byte_str = ""
+    _byte_str = ''
     if isinstance(_bytes, int):
         _bytes = bytes([_bytes])
 
     for _byte in _bytes:
-        _byte_str += f"{int(_byte):02x}"
-        _byte_str += " "
+        _byte_str += f'{int(_byte):02x}'
+        _byte_str += ' '
     return _byte_str
 
 
@@ -30,11 +30,11 @@ def to_bin(_bytes: Union[bytes, int]):
     Returns:
         str: String representation of the byte(s) in binary format
     """
-    _byte_str = ""
+    _byte_str = ''
     if isinstance(_bytes, int):
         _bytes = bytes([_bytes])
 
     for _byte in _bytes:
-        _byte_str += f"{int(_byte):08b}"
-        _byte_str += " "
-    return _byte_str
\ No newline at end of file
+        _byte_str += f'{int(_byte):08b}'
+        _byte_str += ' '
+    return _byte_str
